Module: Docbook::Output::Formats::LibrarySupport

Included in:
DomFormat, InlineFormat
Defined in:
lib/docbook/output/formats/library_support.rb

Overview

Shared library support methods for format classes.

Provides common methods for building multi-book library data and resolving cover images, extracted from InlineFormat and DomFormat to eliminate duplication.

Include this module in any format class that supports library output.

Usage: class MyFormat < BaseFormat include LibrarySupport end